@@ -2,4 +2,4 @@ __all__ = ['track','fit']
 
 from .track import *
 from .fit import *
-name = 'astromet'
+#name = 'astromet'
